import { Temporal } from 'temporal-polyfill';

declare class AocClient {
    private sessionCookie;
    private unlockDateTime;
    private year;
    private day;
    private overwriteFiles;
    private inputFilename;
    private puzzleFilename;
    constructor(sessionCookie: string, unlockDateTime: Temporal.ZonedDateTime, year: number, day: number, overwriteFiles: boolean, inputFilename: string, puzzleFilename: string);
    static getBuilder(): AocClientBuilder;
    savePuzzleMarkdown(): Promise<void>;
    saveInput(): Promise<void>;
    getPuzzleHtml(): Promise<string>;
    getInput(): Promise<string>;
    ensureDayUnlocked(): void;
    isDayUnlocked(): boolean;
}
declare class AocClientBuilder {
    #private;
    protected _sessionCookie?: string;
    protected _year?: number;
    protected _day?: number;
    protected _overwriteFiles: boolean;
    protected _inputFilename: string;
    protected _puzzleFilename: string;
    buildClient(): AocClient;
    getSessionCookieFromDefaultLocations(): AocClientBuilder;
    getSessionCookieFromFile(file: string): AocClientBuilder;
    static getDefaultSessionCookieFile(): string;
    setSessionCookie(sessionCookie: string): AocClientBuilder;
    year(year: number): AocClientBuilder;
    day(day: number): AocClientBuilder;
    latestPuzzleDay(): AocClientBuilder;
    latestEventYear(): AocClientBuilder;
    overwriteFiles(overwrite: boolean): AocClientBuilder;
}

export { AocClient, AocClientBuilder };
